#!/bin/bash

# this is a shell script to update xaseco semi automatic. the script will copy and compare files automatically.
# if there is any difference it will open the editor for edition of the files.
# there are options to edit/compare files before start to copy.
# you can set a default xaseco folder to update as well as a default aseco.php name
# the aseco.php will be renamed if set and chmodded 755
# you also can use two parameter to update more than one xaseco folder
#
# this script needs the editor "vim" to work!!!!!!
#
# copy this file into the same folder as the unpacked xaseco folder from xaseco_nnn.zip, dont forget to chmod it.
#
# usage like "./update.sh PATH FILENAME" or "./update.sh" if a standard is set 
# $1 = xaseco path to update
# $2 = xaseco file name (aseco.php)
#
# ======================= VIM/VIMDIFF commands ==================================== #
#
# all edition is done with vim, commands like that:
# i = insert
# ESC = exit insertmodus
# :w = write file
# :q = exit
# :q! = exit without saving
# /string = jump to string
# :syntax on = syntax highlighting on
#
# ]do = get the content of the other buffer
# ]dp = put the content into the other buffer
# ]ZZ = save and exit buffer
# ]ww = switch buffer
#
# ================================================================================= #
# Author: 			ML aka RookieNouse aka nouseforname @ http://www.tm-forum.com
# Home: 			http://tmf.game-host.org
# Date: 			09.01.2010
# Version:			1.0
# Dependencies: 	vim text editor, unpacked xaseco update in same folder
# ================================================================================= #
#
# ============================ config start ======================================= #

# path to default xaseco folder to update, can be given by shell parameter
XASECOFOLDER='./xaseco_ori'

# name of default xaseco executing file, can be given by shell parameter
XASECOFILE='aseco.php'

# path/name of the files you want to edit first, before start updating, keep empty if not needed
EDITFIRST=		 # eg.: EDITFIRST=(./xaseco/aseco.php ./xaseco/includes/basic.inc.php)  includeing the brackets

# path/name of the files you want to compare first, before start updating, keep empty if not needed
# comnparsion file1 - file2, file3 - file4 etc...
COMPAREFIRST=('./xaseco/aseco.php' './xaseco_ori/xaseco.php'  )	# COMPAREFIRST=('file1' 'file2' 'file3' 'file4')

# ============================ config end ========================================== #

# function to check if files are different
function getdiff() {
	$(diff -qbBwi $1 $2 >/dev/null 2>&1;)
	DIFF=$?
	return $DIFF
}

# check for given path to update
if [ $1 ] ; then
	FOLDER=$1
else
	FOLDER=$XASECOFOLDER
fi

# check for given file name
if [ $2 ] ; then
	FILE=$2
else
	FILE=$XASECOFILE
fi 

# open all files in EDITFIRST array with vim
if [ $EDITFIRST ] ; then
	for i in ${EDITFIRST[*]}
	do
		if [ -f $i ] ; then
			vim $i
		else 
			echo "
	$i is not a file. Update stopped during pre edition of given files!!!
"	
			exit 1
		fi
	done
fi

# compare non config files from COMPAREFIRST array before starting tp update 
if [ $COMPAREFIRST ] ; then
	COUNT=${#COMPAREFIRST[*]};
	for((i=0;i<$COUNT;i+=2)); do 
		if [ -f ${COMPAREFIRST[$i]} ] && [ -f ${COMPAREFIRST[$i+1]} ] ; then
		
			getdiff ${COMPAREFIRST[$i]} ${COMPAREFIRST[$i+1]} ;
		
			if [ $DIFF == 1 ] ; then 
				vimdiff ${COMPAREFIRST[$i]} ${COMPAREFIRST[$i+1]};
			fi
		else 
			echo 'ATTENTION!!!!!' ${COMPAREFIRST[$i]} 'or' ${COMPAREFIRST[$i+1]} 'is not a file!!!'
		fi
	done	
fi

# pause before starting update
read -p 'Press enter to start copy files or ]c to cancel update...'

# check if update folder exist, if not create it.
if [ ! -d $FOLDER ] ; then mkdir $FOLDER; fi

# copy standard files into update folder
cp -r ./xaseco/includes $FOLDER
cp -r ./xaseco/panels $FOLDER
cp -r ./xaseco/plugins $FOLDER
cp -r ./xaseco/styles $FOLDER
cp ./xaseco/aseco.php $FOLDER/$FILE
chmod 755 $FOLDER/$FILE

read -p 'Copy done. Start with config files... [ENTER]'

# make arrays of new config files, ordered by extentions
TPL=("$(find ./xaseco/newinstall -name '*.tpl')")
PHP=("$(find ./xaseco/newinstall -name '*.php')")
XML=("$(find ./xaseco/newinstall -name '*.xml')")

# copy .tpl files, usually never change
for file in $TPL; do 
	cp $file $FOLDER;
done

echo '*.tpl files done'

# copy /includes/*.php config files
for file in $PHP; do 
	STRIP=${file##.*/} # delete path from filename
	if [ ! -f $FOLDER/includes/$STRIP ] ; then
		cp $file $FOLDER/includes;
		
	else
		getdiff $file $FOLDER/includes/$STRIP ;
		if [ $DIFF == 1 ] ; then 
			vimdiff $FOLDER/includes/$STRIP $file;
		fi
	fi
done

echo '*.php files done'

# copy *.xml config files
for file in $XML; do 
	STRIP=${file##.*/} # delete path from filename
	if [ ! -f $FOLDER/$STRIP ] ; then
		cp $file $FOLDER;
		vim $FOLDER/$STRIP;
	else
		getdiff $file $FOLDER/$STRIP ;
		if [ $DIFF == 1 ] ; then 
			vimdiff $FOLDER/$STRIP $file;
		fi
	fi
done

echo -e '*.xml files done'
echo -e ""
echo -e "Xaseco update finished in $FOLDER."
echo -e ""
echo -e "Script written by Nouseforname @ tm-forum.com"
echo -e ""